figaro.coordinates
==================

.. automodule:: figaro.coordinates

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      Jacobian
      Jacobian_in_celestial
      cartesian_to_celestial
      celestial_to_cartesian
      inv_Jacobian
   
   

   
   
   

   
   
   



